@@ -233,6 +233,7 @@ class PGG_diffusion:
         time_stamps = {}
         for node in self._G.nodes():
             time_stamps[node] = self._G.node[node]['time_stamp']
+        print time_stamps
         return time_stamps
 
     def get_states(self):
@@ -248,6 +249,7 @@ class PGG_diffusion:
         return sent_update
 
     def get_seeder(self):
+        print self._infected_node
         return self._infected_node
     #
     # Reset
